@@ -9,7 +9,7 @@
 import math
 import uuid
 from abc import ABC, abstractmethod
-from typing import Tuple, Union, Optional
+from typing import Tuple, Optional
 
 import pygame
 from custom_inherit import doc_inherit
@@ -18,7 +18,7 @@ from pygame import Color
 from pi_touch_gui._utilities import snapped_value_string
 from pi_touch_gui.colors import WHITE, BLACK, MEDIUM_GRAY
 from pi_touch_gui.multitouch.raspberrypi_ts import (TS_PRESS, TS_RELEASE,
-                                                    TS_MOVE, Touch)
+                                                    TS_MOVE)
 
 # Default font name - specify one here if you want something other
 # than the system default.
@@ -42,6 +42,10 @@ class IWidgetInterface(ABC):
         may default to [None, None, None, None].
         """
 
+    @property
+    def sub_widgets(self):
+        return None
+
     @abstractmethod
     def event(self, event, touch) -> Tuple[bool, Optional['Page']]:
         """ Handle touch events, translating them to individual `on_*` calls.
@@ -61,6 +65,16 @@ class IWidgetInterface(ABC):
             The page to transition to, or None to stay on this page
         """
 
+    @abstractmethod
+    def focus(self, enabled):
+        """ Set the widget's focus, for the gestural interface.
+
+        Parameters
+        ----------
+        enabled : bool
+            True if this Widget is receiving focus.
+        """
+
     @abstractmethod
     def can_focus(self):
         """ Return True if this widget can accept focus.
@@ -87,7 +101,7 @@ class IWidgetInterface(ABC):
         """
 
 
-class IWidget(IWidgetInterface):
+class IWidget(IWidgetInterface, ABC):
     """ Widget base class that processes events and holds common state.
 
         Sub-classes can define any or all of the three event handlers:
@@ -208,7 +222,7 @@ class IWidget(IWidgetInterface):
     def size(self) -> Tuple[int, int]:
         """ The width, height extents of the widget.
         """
-        return (self.w, self.h)
+        return self.w, self.h
 
     @property
     def pressed(self) -> bool:
@@ -253,13 +267,6 @@ class IWidget(IWidgetInterface):
                                  f"{type(neighbor)!r}")
 
     def focus(self, enabled):
-        """ Set the widget's focus, for the gestural interface.
-
-        Parameters
-        ----------
-        enabled : bool
-            True if this Widget is receiving focus.
-        """
         self._focus = enabled
 
     def can_focus(self) -> bool:
@@ -382,6 +389,7 @@ class IWidget(IWidgetInterface):
 class IButtonWidget(IWidget):
     """ ButtonWidget base that extends IWidget for push buttons.
     """
+
     @doc_inherit(IWidget.__init__, style='numpy_with_merge')
     def __init__(self, position, size, function=None, **kwargs):
         """
@@ -433,7 +441,7 @@ class IButtonWidget(IWidget):
             self.render_focus(surface)
 
 
-class IControlWidget(IWidget):
+class IControlWidget(IWidget, ABC):
     """ ControlWidget base that extends IWidget for input controls.
     """
 
@@ -472,7 +480,7 @@ class IControlWidget(IWidget):
         self.snap_value = 1 if snap_value is None else snap_value
         self.snap_value = 0.01 if self.snap_value < 0.01 else self.snap_value
 
-        self.min_val, self.max_val = (min_max)
+        self.min_val, self.max_val = min_max
         # Value is in 0..1, where adjusted_value is in min_val..max_val
         self.range = self.max_val - self.min_val
 
@@ -506,11 +514,12 @@ class IControlWidget(IWidget):
 
         Parameters
         ----------
-        value : float
+        adjusted_value : float
             Widget's external value in min_val..max_val
 
         Returns
         -------
+        float
             Widget's internal value in 0..1
         """
         # map [min_val, max_val] to [0, 1]
