@@ -14,13 +14,13 @@ import math
 from typing import List, Optional, NoReturn
 
 import pygame
-from pygame.constants import *
+from pygame.constants import (KEYDOWN, K_SPACE, K_RETURN, K_UP, K_DOWN, K_LEFT,
+                              K_RIGHT, KEYUP, K_ESCAPE, K_EQUALS, K_MINUS)
 
 from pi_touch_gui._utilities import backlog_error
 from pi_touch_gui._widget_bases import IWidget, IWidgetInterface
 from pi_touch_gui.colors import BLACK
 from pi_touch_gui.multitouch.raspberrypi_ts import Touchscreen, TS_RELEASE
-from pi_touch_gui.widget_buttons import Button
 
 LOG = logging.getLogger(__name__)
 
@@ -36,11 +36,13 @@ class Page(object):
     GO_NEIGHBORLESS = [-1, 1, -1, 1]
     GO_NAMES = ["Up", "Down", "Left", "Right"]
 
-    def __init__(self, widgets=None, background=None, function=None):
+    def __init__(self, name, widgets=None, background=None, function=None):
         """ A collection of widgets that make up an interaction page.
 
         Parameters
         ----------
+        name : String
+            Name of the page for internal and callback reference
         widgets : List[IWidget]
         background : str
             Background image resource filepath for this Page
@@ -50,7 +52,8 @@ class Page(object):
         """
         # If no widgets added on init, they can be added with `add_widgets()`
         # later.
-        self._widgets = [] if widgets is None else widgets
+        self._name = name
+        self._widgets = widgets or []
 
         if background is not None:
             self._background = pygame.image.load(background).convert()
@@ -68,6 +71,10 @@ class Page(object):
         self._last_adjustment = pygame.time.get_ticks()
         self.adjustment_rate = 100
 
+    @property
+    def name(self):
+        return self._name
+
     @property
     def background(self):
         return self._background
@@ -125,12 +132,12 @@ class Page(object):
         for widget in widgets:
             # See if this is a widget container...
             found_widget = None
-            try:
+            sub_widgets = widget.sub_widgets
+            if sub_widgets:
                 # Assume the widget is a widget container and assert if not
-                sub_widgets = widget._widgets
                 found_widget = self._scan_for_widget_by_id(sub_widgets,
                                                            widget_id)
-            except AttributeError:
+            else:
                 if widget.id == widget_id:
                     found_widget = widget
             if found_widget is not None:
@@ -183,16 +190,17 @@ class Page(object):
         for idx, widget in enumerate(widgets):
             # See if this is a widget container...
             found_widget = None
-            try:
+            sub_widgets = widget.sub_widgets
+            if sub_widgets:
                 # Assume the widget is a widget container and assert if not
-                sub_widgets = widget._widgets
                 found_widget = self._scan_for_widget_by_id(sub_widgets,
                                                            widget_id)
-            except AttributeError:
+            else:
                 if widget.id == widget_id:
                     try:
                         found_widget = widgets[idx + step]
                     except Exception as e:
+                        LOG.error(f"Unmanaged Exception {type(e)}: {e}")
                         return None
             if found_widget is not None:
                 return found_widget
@@ -314,9 +322,6 @@ class Page(object):
                 # Neighbor as a widget ID or index
                 next_widget = self.find_widget(next_widget)
 
-            if test_widget.label == 'group':
-                pause = True
-
             # In case we instantiated a neighbor, store it
             test_widget.neighbors[direction] = next_widget
 
@@ -336,8 +341,8 @@ class Page(object):
             if self._focus_widget is not None:
                 self._focus_widget.focus(False)
             next_widget.focus(True)
-        except Exception:
-            pause = True
+        except Exception as e:
+            LOG.error(f"Unmanaged Exception {type(e)}: {e}")
         self._focus_widget = next_widget
         self._prev_focus_widget = next_widget
 
@@ -418,7 +423,7 @@ class GUI(object):
 
         if self._faded:
             self.set_brightness(self._bright_level)
-            self.fade = False
+            self._faded = False
         if self._blacked:
             self.set_light(True)
             self._blacked = False
@@ -451,7 +456,7 @@ class GUI(object):
         with open('/sys/class/backlight/rpi_backlight/bl_power', 'w') as f:
             f.write(blank_str)
 
-    def run(self, page) -> NoReturn:
+    def run(self, page, callback=None, cb_rate=None) -> NoReturn:
         """ Run the GUI, staring with the initial Page.
 
         Does not return, but does an exit() when done. Wrapping
@@ -460,6 +465,17 @@ class GUI(object):
         Parameters
         ----------
         page : Page
+            The starting page to display
+        callback : Callable[GUI, Page]
+            An optional method to inject into the GUI main loop, for managing
+            events and activities. This method SHOULD NOT take much time,
+            as it is in the middle of the display loop.  Time consuming
+            activities should be set up in a separate thread or process, with
+            this callback doing quick actions only.
+        cb_rate : Int
+            The (approximate) number of milliseconds between calls to the
+            callback (it helps if it's some multiple of 1/60, as the primary
+            loop rate is 60 frames a second).
         """
         self._current_page = page
         self._first_page = page
@@ -467,7 +483,7 @@ class GUI(object):
 
         self._touchscreen.run()
 
-        fpsClock = pygame.time.Clock()
+        fps_clock = pygame.time.Clock()
 
         def handle_touches(e, t):
             """ Call the `Page.touch_handler()` to process an event. """
@@ -493,18 +509,24 @@ class GUI(object):
             touch.on_move = handle_touches
 
         try:
+            last_hook_ms = pygame.time.get_ticks()
             while self._running:
                 # Deal with screen fade and blackout
                 time = pygame.time.get_ticks()
                 # deltaTime in seconds.
-                deltaTime = (time - self.last_event) / 1000.0
-                if deltaTime > self.BLACKOUT_TIME:
+                delta_time = (time - self.last_event) / 1000.0
+                if delta_time > self.BLACKOUT_TIME:
                     self.set_light(False)
                     self._blacked = True
-                elif deltaTime > self.FADE_TIME:
+                elif delta_time > self.FADE_TIME:
                     self.set_brightness(self.FADE_LEVEL)
                     self._faded = True
 
+                # Call external hook if specified
+                if callback is not None and (time - last_hook_ms) > cb_rate:
+                    last_hook_ms = time
+                    callback(self, self._current_page)
+
                 # Render the current page
                 self._current_page.render(self._touchscreen.surface)
                 pygame.display.flip()
@@ -533,10 +555,7 @@ class GUI(object):
                             if event.key in [K_SPACE, K_RETURN]:
                                 if page.is_focused():
                                     new_page = page.release_widget()
-                                    widget = page._focus_widget
-                                    if (isinstance(widget, Button)
-                                            and widget.behavior != Button.HOLD):
-                                        page.focus_widget(False)
+                                    page.focus_widget(False)
                                 else:
                                     page.focus_widget(True)
 
@@ -557,10 +576,10 @@ class GUI(object):
                                   f"{type(new_page)!r}")
 
                 # Lock it into the framerate
-                fpsClock.tick(self.FPS)
+                fps_clock.tick(self.FPS)
 
         except Exception as e:
-            backlog_error(e, f"Unmanaged exception")
+            backlog_error(e, f"Unmanaged Exception {type(e)}: {e}")
         finally:
             self.reset_display()
             LOG.info("Stopping touchscreen thread...")
