@@ -57,11 +57,11 @@ class Touch(object):
 
     @property
     def position(self):
-        return (self.x, self.y)
+        return self.x, self.y
 
     @property
     def last_position(self):
-        return (self.last_x, self.last_y)
+        return self.last_x, self.last_y
 
     @property
     def valid(self):
@@ -74,9 +74,9 @@ class Touch(object):
     @id.setter
     def id(self, value):
         if value != self._id:
-            if value == -1 and not TS_RELEASE in self.events:
+            if value == -1 and TS_RELEASE not in self.events:
                 self.events.append(TS_RELEASE)
-            elif not TS_PRESS in self.events:
+            elif TS_PRESS not in self.events:
                 self.events.append(TS_PRESS)
 
         self._id = value
@@ -87,7 +87,7 @@ class Touch(object):
 
     @x.setter
     def x(self, value):
-        if value != self._x and not TS_MOVE in self.events:
+        if value != self._x and TS_MOVE not in self.events:
             self.events.append(TS_MOVE)
         self.last_x = self._x
         self._x = value
@@ -98,7 +98,7 @@ class Touch(object):
 
     @y.setter
     def y(self, value):
-        if value != self._y and not TS_MOVE in self.events:
+        if value != self._y and TS_MOVE not in self.events:
             self.events.append(TS_MOVE)
         self.last_y = self._y
         self._y = value
@@ -128,7 +128,8 @@ class Touchscreen(object):
     EVENT_SIZE = struct.calcsize(EVENT_FORMAT)
 
     def __init__(self, device=None, size=None):
-        self._device = self.TOUCHSCREEN_EVDEV_NAME if device is None else device
+        self._device = (self.TOUCHSCREEN_EVDEV_NAME
+                        if device is None else device)
         self.size = (800, 480) if size is None else size
 
         self._running = False
