@@ -7,8 +7,8 @@
 
 import pygame
 
-from colors import (WHITE, MEDIUM_GRAY, BLUE, RED, BLACK, DARK_RED, GREEN, CYAN,
-                    MAGENTA)
+from colors import (WHITE, MEDIUM_GRAY, BLUE, RED, BLACK, DARK_RED, GREEN,
+                    CYAN, MAGENTA)
 from gui import Page
 from tests._utilities import fake_data_graph_function
 from widget_buttons import Button, ButtonGroup
@@ -141,24 +141,21 @@ def sampler_page():
     # =========================================================
     # Button Group
     # =========================================================
-    def toggle_function(button, pushed):
-        print(f"### {button.label} pushed {pushed}")
 
     _color_buttons_label = Label((300, 105), (100, 25),
                                  label="Pick One")
 
     _red_button = Button((300, 130), (100, 50),
-                         label="Red", color2=RED,
-                         behavior=Button.TOGGLE,
-                         function=toggle_function)
+                         label="Red",
+                         color2=RED,
+                         behavior=Button.TOGGLE)
     _green_button = Button((300, 185), (100, 50),
-                           label="Green",color2=GREEN,
-                           behavior=Button.TOGGLE,
-                           function=toggle_function)
-    _blue_button = Button((300, 240), (100, 50),
-                          label="Blue", color2=BLUE,
-                          behavior=Button.TOGGLE,
-                          function=toggle_function)
+                           label="Green",
+                           color2=GREEN,
+                           behavior=Button.TOGGLE)
+    _blue_button = Button((300, 240), (100, 50), label="Blue",
+                          color2=BLUE,
+                          behavior=Button.TOGGLE)
 
     _color_group = ButtonGroup([_red_button, _green_button, _blue_button])
 
@@ -182,7 +179,7 @@ def sampler_page():
 
     def _graph_button_update(graph, size):
         global _dial_value, _slider_h_value, _slider_v_value
-        global last_update, _max_track_samples
+        global _max_track_samples
         global _track_1_data, _track_2_data, _track_3_data
         global _last_track_update
 
@@ -225,8 +222,8 @@ def sampler_page():
                        snap_value=.1,
                        label_color1=BLACK, color1=MEDIUM_GRAY, color2=BLUE,
                        dynamic=False, function=_slider_h_control_func)
-    _fake_graph = Graph((680, 240), (110, 150), min_max=(-100, 100), quiet=True,
-                        function=fake_data_graph_function)
+    _fake_graph = Graph((680, 240), (110, 150), min_max=(-100, 100),
+                        quiet=True, function=fake_data_graph_function)
 
     # =========================================================
     # Define keyboard navigation grid
@@ -286,26 +283,29 @@ def sampler_page():
         _back_button.function = go_back
         _sampler_page.background = background
 
-    _sampler_page = Page(
-        # Tests background image, Button, RoundedButton, DynamicButton,
-        # ToggleButton, ButtonGroup, Label, Indicator, ...
-        [
-            # Putting a non-focus element first to test that case in
-            # keyboard control
-            _up_dn_indicator, _up_button, _dn_button,
-            _back_button, _do_nothing_button, _next_button,
-            _boop_button, _boop_indicator,
+    # Tests background image, Button, RoundedButton, DynamicButton,
+    # ToggleButton, ButtonGroup, Label, Indicator, ...
+    _sampler_page = Page('sampler',
+                         [
+                             # Putting a non-focus element first to test
+                             # that case in keyboard control
+                             _up_dn_indicator, _up_button, _dn_button,
+                             _back_button, _do_nothing_button, _next_button,
+                             _boop_button, _boop_indicator,
 
-            _count_buttons_label,
-            _one_button, _two_button, _three_button, _count_reset_button,
+                             _count_buttons_label,
+                             _one_button, _two_button, _three_button,
+                             _count_reset_button,
 
-            _color_buttons_label,
-            _red_button, _green_button, _blue_button, _color_group,
+                             _color_buttons_label,
+                             _red_button, _green_button, _blue_button,
+                             _color_group,
 
-            _control_graph, _control_dial, _v_slider, _h_slider,
-            _fake_graph
-        ]
-    )
+                             _control_graph, _control_dial, _v_slider,
+                             _h_slider,
+                             _fake_graph
+                         ]
+                         )
     # Add a custom attribute, which is monkey-patching at its worst
     _sampler_page.config = _configure_page
 
